==> streamlit_extras-0.0.7.tar.gz: streamlit_extras-0.0.7/README.md <==

<a href="https://extras.streamlitapp.com" title="Python Version"><img src="https://static.streamlit.io/badges/streamlit_badge_black_white.svg"></a><br>
<a href="https://github.com/arnaudmiribel/streamlit-extras/" title="Python Version"><img src="https://img.shields.io/badge/Python-3.9%2B-blue&style=flat"></a>
<a href="https://badge.fury.io/py/streamlit-extras"><img src="https://badge.fury.io/py/streamlit-extras.svg" alt="PyPI version" height="18"></a>
<a href="https://hits.seeyoufarm.com"><img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Farnaudmiribel%2Fstreamlit-extras&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=visits&edge_flat=false"/></a>


# 🪢 streamlit-extras


<strong>A Python library with useful Streamlit extras</strong>

`streamlit-extras` is a Python library putting together useful Streamlit bits of code (<b><i>extras</i></b>).

---

<p align="center">
     Try out and explore available extras in our playgrounds at <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a>.<br><br>
     <img src="https://user-images.githubusercontent.com/7164864/186383332-147e820d-cd02-4962-b8b9-91fe9f675dfe.gif" width="500px"></img>
</p>



---

## Highlights

- 📙&nbsp; <b>Discover:</b> Visit the gallery <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a> to discover all extras in their natural habitat
- 🛝&nbsp; <b>Try:</b> The gallery comes with a Streamlit-based playground for some extras. Try it before you <strike>buy</strike> install it!
- ⬇️&nbsp; <b>Install:</b> `streamlit-extras` is a PyPI package with all extras included. Catch them all using pip!
- 🫴&nbsp; <b>Share:</b> Go ahead and share your own extras, it's just a PR away!

## Getting Started

### Installation

```
pip install streamlit-extras
```

### Usage

Here's an example with one of the easiest extras around, <a href="https://extras.streamlitapp.com/Toggle%20button">stoggle</a>
```python
from streamlit_extras.stoggle import stoggle

stoggle("Summary", "More content that's hidden by default!")
```

## Documentation

Visit <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a>

## Contribution

PRs are welcome! Guidelines here at <a href="https://extras.streamlitapp.com/Contribute">extras.streamlitapp.com/Contribute</a>

<sup>README template taken from <a href="https://github.com/LukasMasuch/streamlit-pydantic">LukasMasuch/streamlit-pydantic</a></sup>

==> streamlit_extras-0.2.0.tar.gz: streamlit_extras-0.2.0/README.md <==

<a href="https://extras.streamlitapp.com" title="Python Version"><img src="https://static.streamlit.io/badges/streamlit_badge_black_white.svg"></a><br>
<a href="https://github.com/arnaudmiribel/streamlit-extras/" title="Python Version"><img src="https://img.shields.io/badge/Python-3.9%2B-blue&style=flat"></a>
<a href="https://badge.fury.io/py/streamlit-extras"><img src="https://badge.fury.io/py/streamlit-extras.svg" alt="PyPI version" height="18"></a>
<a href="https://hits.seeyoufarm.com"><img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Farnaudmiribel%2Fstreamlit-extras&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=visits&edge_flat=false"/></a>


# 🪢 streamlit-extras


<strong>A Python library with useful Streamlit extras</strong>

`streamlit-extras` is a Python library putting together useful Streamlit bits of code (<b><i>extras</i></b>).

---

<p align="center">
     Try out and explore available extras in our playgrounds at <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a>.<br><br>
     <img src="https://user-images.githubusercontent.com/7164864/186383332-147e820d-cd02-4962-b8b9-91fe9f675dfe.gif" width="500px"></img>
</p>



---

## Highlights

- 📙&nbsp; <b>Discover:</b> Visit the gallery <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a> to discover all extras in their natural habitat.
- 🛝&nbsp; <b>Try:</b> The gallery comes with a Streamlit-based playground for some extras. Try it before you <strike>buy</strike> install it!
- ⬇️&nbsp; <b>Install:</b> `streamlit-extras` is a PyPI package with all extras included. Get them all using pip!
- 🫴&nbsp; <b>Share:</b> Go ahead and share your own extras, it's just [a PR away](https://extras.streamlitapp.com/Contribute)!

## Getting Started

### Installation

```
pip install streamlit-extras
```

### Usage

Here's an example with one of the easiest extras around, <a href="https://extras.streamlitapp.com/Toggle%20button">stoggle</a>
```python
from streamlit_extras.stoggle import stoggle

stoggle(
    "Click me!",
    """🥷 Surprise! Here's some additional content""",
)
```

<img src="https://user-images.githubusercontent.com/16867691/192553812-f91c801b-e820-470b-84c6-4563504c6ce5.gif"></img>

## Documentation

Visit <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a>

## Contribution

PRs are welcome! Guidelines here at <a href="https://extras.streamlitapp.com/Contribute">extras.streamlitapp.com/Contribute</a>

<sup>README template taken from <a href="https://github.com/LukasMasuch/streamlit-pydantic">LukasMasuch/streamlit-pydantic</a></sup>
